<?php
/*
 * © Copyright 2007, 2008 IntraHealth International, Inc.
 * 
 * This File is part of iHRIS
 * 
 * iHRIS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * The page class for displaying the history of a form associated with a person's record.
 * @package iHRIS
 * @subpackage Common
 * @access public
 * @author Luke Duncan <lduncan@intrahealth.org>
 * @copyright Copyright &copy; 2007, 2008 IntraHealth International, Inc. 
 * @since v2.0.0
 * @version v2.0.0
 */


/**
 * The page class for displaying the history of a form associated with a person's record.
 * @package iHRIS
 * @subpackage Common
 * @access public
 */
class iHRIS_PageHistory extends I2CE_Page {
        
    /**
     * @var I2CE_Form The history object being displayed by this page.
     */
    protected $history;
        
    /**
     * Return a prefix to be used for templates associated with this page.
     * @return string
     */
    protected function getPrefix() { return ""; }

    /**
     * Load the HTML template files for viewing an object's history.
     */
    protected function loadHTMLTemplates() {
        parent::loadHTMLTemplates();
        $this->template->appendFileById( "menu_view_" . $this->getPrefix() . "link.html", "li", "navBarUL", true );
    }
        
    /**
     * Load the history object for this page.
     */
    protected function loadObjects() {
        $factory = I2CE_FormFactory::instance();
        $this->history = $factory->createContainer( "person".'|'. $this->get('id') );
        $this->history->populate();
    }
        
    /**
     * Perform the main actions of the page.
     */
    protected function action() {
        parent::action();
        $this->loadObjects();
        $orderBy = array();
        if ( $this->get_exists('order_by') ) {
            $orders = $this->get('order_by');
            if (is_array($orders) && array_key_exists($form,$orders) && is_array($orders[$form])) {
                $orderBy[$form]  = array_keys($orders[$form]);
            }
        }
        $this->template->setForm( $this->history );
        $forms = preg_split('/\s*,\s*/',$this->request('form'),-1,PREG_SPLIT_NO_EMPTY);
        if (count($forms) == 0) {
            return;
        }
        $parentForms = array($this->history);
        $formsIndex = array();
        foreach ($forms as $form) {
            $childForms = array();
            $formIndex[$form] = array();
            foreach ($parentForms as $parentForm) {
                $parentForm->populateChildren( $form , $orderBy);
                if (array_key_exists($form,$parentForm->children) && is_array($parentForm->children[$form]) && count($parentForm->children[$form]) > 0) {
                    $formsIndex[$form][$parentForm->getFormID()] = $parentForm->children[$form];
                    $childForms = array_merge($childForms,$parentForm->children[$form]);
                }
            }
            if (count($childForms) == 0) {
                return true;
            }
            $parentForms = $childForms;
            $childForms = array();
        }

        end($forms);
        $form = current($forms);
        
        $i = 0;
        foreach ($parentForms as $formObj) {
            if ( $i == 0 ) {
                $this->template->setDisplayData( "history_header", $formObj->getDisplayName() . " History" );        
            } else {
                $this->template->appendFileById( "hr.html", "hr", "history" );
            }
            $i++;
            $node = $this->template->appendFileById( "view_" . $this->getPrefix() . $form . ".html", "div", "history" );
            $this->template->setForm( $formObj, $node );
            if (!$this->get_exists('show_edit')) {
                $this->template->findAndRemoveNodes( "//div[@class='editRecord']" );
            }
            $this->template->findAndRemoveNodes( "//span[@history='false']" );
        }
    }
        
}


# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
